window.Gleam.initSearch([{"doc":"mapped","title":"mapped","content":"# Mapped\n\n[![Package Version](https://img.shields.io/hexpm/v/mapped)](https://hex.pm/packages/mapped)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/mapped/)\n\nAn implementation of a Bidirectional Map (BiMap) in pure Gleam.\n\n```sh\ngleam add mapped@1\n```\n```gleam\nimport mapped\n\npub fn main() {\n  let numbers_to_words = mapped.from_list([\n    #(1, &quot;one&quot;)\n    #(2, &quot;two&quot;)\n    #(3, &quot;three&quot;)\n    #(4, &quot;four&quot;)\n    #(5, &quot;five&quot;)\n  ])\n  \n  let assert Ok(word) = mapped.get_by_left(4) // -&gt; &quot;four&quot;\n  let assert Ok(number) = mapped.get_by_right(&quot;three&quot;) // -&gt; 3\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/mapped&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"mapped","title":"BiMap","content":"pub opaque type BiMap(left, right)\n\n\nSynonyms:\nmapped.BiMap\nmapped BiMap","url":"mapped.html#BiMap"},{"doc":"mapped","title":"delete_by_left","content":"pub fn delete_by_left(\n  from map: BiMap(a, b),\n  remove key: a,\n) -&gt; BiMap(a, b)\n Creates a new map from the given map, with all the same entries except for\n the one with the given left value, if it exists.\n \n ## Examples\n \n \n mapped.from_list([#(&quot;one&quot;, 1), #(&quot;two&quot;, 2), #(&quot;wrong&quot;, 83)]) |&gt; mapped.delete_by_left(&quot;wrong&quot;)\n // -&gt; { &quot;one&quot; &lt;&gt; 1, &quot;two&quot; &lt;&gt; 2 }\n \n \n \n mapped.from_list([#(&quot;one&quot;, 1), #(&quot;two&quot;, 2)]) |&gt; mapped.delete_by_left(&quot;three&quot;)\n // -&gt; { &quot;one&quot; &lt;&gt; 1, &quot;two&quot; &lt;&gt; 2 }\n \n \nSynonyms:\nmapped.delete_by_left\nmapped delete_by_left","url":"mapped.html#delete_by_left"},{"doc":"mapped","title":"delete_by_right","content":"pub fn delete_by_right(\n  from map: BiMap(a, b),\n  remove key: b,\n) -&gt; BiMap(a, b)\n Creates a new map from the given map, with all the same entries except for\n the one with the given right value, if it exists.\n \n ## Examples\n \n \n mapped.from_list(\n   [#(&quot;one&quot;, 1), #(&quot;two&quot;, 2), #(&quot;wrong&quot;, 83)]\n ) |&gt; mapped.delete_by_left(&quot;wrong&quot;)\n // -&gt; { &quot;one&quot; &lt;&gt; 1, &quot;two&quot; &lt;&gt; 2 }\n \n \n \n mapped.from_list([#(&quot;one&quot;, 1), #(&quot;two&quot;, 2)]) |&gt; mapped.delete_by_left(&quot;three&quot;)\n // -&gt; { &quot;one&quot; &lt;&gt; 1, &quot;two&quot; &lt;&gt; 2 }\n \n \nSynonyms:\nmapped.delete_by_right\nmapped delete_by_right","url":"mapped.html#delete_by_right"},{"doc":"mapped","title":"each","content":"pub fn each(\n  in map: BiMap(a, b),\n  run callback: fn(a, b) -&gt; c,\n) -&gt; Nil\n Runs a function for each left-right pair in the map, discarding the result.\nSynonyms:\nmapped.each\nmapped each","url":"mapped.html#each"},{"doc":"mapped","title":"filter","content":"pub fn filter(\n  in map: BiMap(a, b),\n  keeping predicate: fn(a, b) -&gt; Bool,\n) -&gt; BiMap(a, b)\n Creates a new map from the given map, including only left-right pairs for which\n the given function returns true.\n \nSynonyms:\nmapped.filter\nmapped filter","url":"mapped.html#filter"},{"doc":"mapped","title":"fold","content":"pub fn fold(\n  over map: BiMap(a, b),\n  from initial: c,\n  with callback: fn(c, a, b) -&gt; c,\n) -&gt; c\n Iterates over the given map, folding the left and right values into a single value.\n \nSynonyms:\nmapped.fold\nmapped fold","url":"mapped.html#fold"},{"doc":"mapped","title":"from_dict","content":"pub fn from_dict(dict: Dict(a, b)) -&gt; BiMap(a, b)\n Creates a map from a given dict, mapping the values of the dict\n to the keys as well.\n \n ## Examples\n \n \n dict.from_list([#(&quot;wibble&quot;, 1), #(&quot;wobble&quot;, 2)]) |&gt; mapped.from_dict\n // -&gt; { &quot;wibble&quot; &lt;&gt; 1, &quot;wobble&quot; &lt;&gt; 2 }\n \n \nSynonyms:\nmapped.from_dict\nmapped from_dict","url":"mapped.html#from_dict"},{"doc":"mapped","title":"from_list","content":"pub fn from_list(list: List(#(a, b))) -&gt; BiMap(a, b)\n Creates a map from a list of tuples containing a left and right value.\n \n ## Examples\n \n \n mapped.from_list([#(1, 2), #(3, 4)])\n // -&gt; { 1 &lt;&gt; 2, 3 &lt;&gt; 4 }\n \n \nSynonyms:\nmapped.from_list\nmapped from_list","url":"mapped.html#from_list"},{"doc":"mapped","title":"get_by_left","content":"pub fn get_by_left(\n  from map: BiMap(a, b),\n  get key: a,\n) -&gt; Result(b, Nil)\n Returns the right value associated with this left value, if it exists.\n \n ## Examples\n \n \n mapped.from_list([#(&quot;one&quot;, 1), #(&quot;two&quot;, 2)]) |&gt; mapped.get_by_left(&quot;one&quot;)\n // -&gt; Ok(1)\n \n \n \n mapped.from_list([#(&quot;one&quot;, 1), #(&quot;two&quot;, 2)]) |&gt; mapped.get_by_left(&quot;three&quot;)\n // -&gt; Error(Nil)\n \n \nSynonyms:\nmapped.get_by_left\nmapped get_by_left","url":"mapped.html#get_by_left"},{"doc":"mapped","title":"get_by_right","content":"pub fn get_by_right(\n  from map: BiMap(a, b),\n  get key: b,\n) -&gt; Result(a, Nil)\n Returns the left value associated with this right value, if it exists.\n \n ## Examples\n \n \n mapped.from_list([#(&quot;one&quot;, 1), #(&quot;two&quot;, 2)]) |&gt; mapped.get_by_right(2)\n // -&gt; Ok(&quot;two&quot;)\n \n \n \n mapped.from_list([#(&quot;one&quot;, 1), #(&quot;two&quot;, 2)]) |&gt; mapped.get_by_right(14)\n // -&gt; Error(Nil)\n \n \nSynonyms:\nmapped.get_by_right\nmapped get_by_right","url":"mapped.html#get_by_right"},{"doc":"mapped","title":"has_left","content":"pub fn has_left(map: BiMap(a, b), key: a) -&gt; Bool\n Returns whether the map contains an entry with the given left value.\n \n ## Examples\n \n \n mapped.from_list([#(&quot;one&quot;, 1), #(&quot;two&quot;, 2)]) |&gt; mapped.has_left(&quot;three&quot;)\n // -&gt; False\n \n \nSynonyms:\nmapped.has_left\nmapped has_left","url":"mapped.html#has_left"},{"doc":"mapped","title":"has_right","content":"pub fn has_right(map: BiMap(a, b), key: b) -&gt; Bool\n Returns whether the map contains an entry with the given right value.\n \n ## Examples\n \n \n mapped.from_list([#(&quot;one&quot;, 1), #(&quot;two&quot;, 2)]) |&gt; mapped.has_right(2)\n // -&gt; True\n \n \nSynonyms:\nmapped.has_right\nmapped has_right","url":"mapped.html#has_right"},{"doc":"mapped","title":"insert","content":"pub fn insert(\n  into map: BiMap(a, b),\n  left left: a,\n  right right: b,\n) -&gt; BiMap(a, b)\n Creates a new map from the given map, with all the same entries with an extra\n entry containing the left and right values provided.\n \n If an entry already exists with the given left or right value, it is removed.\n \n ## Examples\n \n \n mapped.from_list([#(1, 2), #(3, 4)]) |&gt; mapped.insert(5, 6)\n // -&gt; { 1 &lt;&gt; 2, 3 &lt;&gt; 4, 5 &lt;&gt; 6 }\n \n \n \n mapped.from_list([#(1, 2), #(3, 4)]) |&gt; mapped.insert(5, 4)\n // -&gt; { 1 &lt;&gt; 2, 5 &lt;&gt; 4 }\n \n \nSynonyms:\nmapped.insert\nmapped insert","url":"mapped.html#insert"},{"doc":"mapped","title":"inspect","content":"pub fn inspect(map: BiMap(a, b)) -&gt; String\n Converts a map to a string, allowing you to view its contents.\n This should only be used for debugging the contents of a map.\n \n The output format of this is not guaranteed and may change any time.\n \nSynonyms:\nmapped.inspect\nmapped inspect","url":"mapped.html#inspect"},{"doc":"mapped","title":"left_to_right","content":"pub fn left_to_right(map: BiMap(a, b)) -&gt; Dict(a, b)\n Creates a dict mapping the left values of the given map to te right values.\n \n ## Examples\n \n \n mapped.from_list([#(&quot;wibble&quot;, 1), #(&quot;wobble&quot;, 2)]) |&gt; mapped.left_to_right\n // -&gt; dict.from_list([#(&quot;wibble&quot;, 1), #(&quot;wobble&quot;, 2)])\n \n \nSynonyms:\nmapped.left_to_right\nmapped left_to_right","url":"mapped.html#left_to_right"},{"doc":"mapped","title":"left_values","content":"pub fn left_values(map: BiMap(a, b)) -&gt; List(a)\n Returns a list containing the left values of the given map.\n \n The order of the resulting list is not guaranteed.\n \n ## Examples\n \n \n mapped.from_list([#(&quot;wibble&quot;, 1), #(&quot;wobble&quot;, 2)]) |&gt; mapped.left_values\n // -&gt; [&quot;wibble&quot;, &quot;wobble&quot;]\n \n \nSynonyms:\nmapped.left_values\nmapped left_values","url":"mapped.html#left_values"},{"doc":"mapped","title":"new","content":"pub fn new() -&gt; BiMap(a, b)\n Creates an new empty map.\n \nSynonyms:\nmapped.new\nmapped new","url":"mapped.html#new"},{"doc":"mapped","title":"right_to_left","content":"pub fn right_to_left(map: BiMap(a, b)) -&gt; Dict(b, a)\n Creates a dict mapping the right values of the given map to te left values.\n \n ## Examples\n \n \n mapped.from_list([#(&quot;wibble&quot;, 1), #(&quot;wobble&quot;, 2)]) |&gt; mapped.right_to_left\n // -&gt; dict.from_list([#(1, &quot;wibble&quot;), #(2, &quot;wobble&quot;)])\n \n \nSynonyms:\nmapped.right_to_left\nmapped right_to_left","url":"mapped.html#right_to_left"},{"doc":"mapped","title":"right_values","content":"pub fn right_values(map: BiMap(a, b)) -&gt; List(b)\n Returns a list containing the right values of the given map.\n \n The order of the resulting list is not guaranteed.\n \n ## Examples\n \n \n mapped.from_list([#(&quot;wibble&quot;, 1), #(&quot;wobble&quot;, 2)]) |&gt; mapped.right_values\n // -&gt; [1, 2]\n \n \nSynonyms:\nmapped.right_values\nmapped right_values","url":"mapped.html#right_values"},{"doc":"mapped","title":"size","content":"pub fn size(of map: BiMap(a, b)) -&gt; Int\n Returns the number of entries in the map. Runs in O(1) time.\n \n ## Examples\n \n \n mapped.from_list([#(1, 2), #(3, 4)]) |&gt; mapped.size()\n // -&gt; 2\n \n \nSynonyms:\nmapped.size\nmapped size","url":"mapped.html#size"},{"doc":"mapped","title":"to_list","content":"pub fn to_list(map: BiMap(a, b)) -&gt; List(#(a, b))\n Converts a map into a list of tuples containing the right and left values\n of each entry.\n \n The order of the resulting list is not guaranteed.\n \n ## Examples\n \n \n mapped.new() |&gt; mapped.to_list\n // -&gt; []\n \n \n \n mapped.from_list([#(1, 2), #(3, 4)]) |&gt; mapped.to_list\n // -&gt; [#(1, 2), #(3, 4)]\n \n \nSynonyms:\nmapped.to_list\nmapped to_list","url":"mapped.html#to_list"},{"doc":"mapped","title":"mapped","content":" An implementation of a [Bidirectional Map](https://en.wikipedia.org/wiki/Bidirectional_map) in pure Gleam, using two Dicts.\n \n Bidirectional Maps (or BiMaps) are useful when two sets of data map between each other in both directions.  \n For example, converting numbers to their word equivalents:\n \n ```gleam\n let numbers_to_words = mapped.from_list([\n   #(1, &quot;one&quot;)\n   #(2, &quot;two&quot;)\n   #(3, &quot;three&quot;)\n   #(4, &quot;four&quot;)\n   #(5, &quot;five&quot;)\n ])\n \n let assert Ok(word) = mapped.get_by_left(4) // -&gt; &quot;four&quot;\n let assert Ok(number) = mapped.get_by_right(&quot;three&quot;) // -&gt; 3\n ```\n \n A single data structure can be used to perform both conversions.\n ","url":"mapped.html"}]);